==> zio-aws-ecs_2.13-5.17.155.1-sources.jar: zio/aws/ecs/model/UpdateTaskSetResponse.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateTaskSetResponse(
    taskSet: Option[zio.aws.ecs.model.TaskSet] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.UpdateTaskSetResponse = {
    import UpdateTaskSetResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.UpdateTaskSetResponse
      .builder()
      .optionallyWith(taskSet.map(value => value.buildAwsValue()))(_.taskSet)
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.UpdateTaskSetResponse.ReadOnly =
    zio.aws.ecs.model.UpdateTaskSetResponse.wrap(buildAwsValue())
}
object UpdateTaskSetResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.UpdateTaskSetResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.UpdateTaskSetResponse = zio.aws.ecs.model
      .UpdateTaskSetResponse(taskSet.map(value => value.asEditable))
    def taskSet: Option[zio.aws.ecs.model.TaskSet.ReadOnly]
    def getTaskSet: ZIO[Any, AwsError, zio.aws.ecs.model.TaskSet.ReadOnly] =
      AwsError.unwrapOptionField("taskSet", taskSet)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.UpdateTaskSetResponse
  ) extends zio.aws.ecs.model.UpdateTaskSetResponse.ReadOnly {
    override val taskSet: Option[zio.aws.ecs.model.TaskSet.ReadOnly] = scala
      .Option(impl.taskSet())
      .map(value => zio.aws.ecs.model.TaskSet.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.UpdateTaskSetResponse
  ): zio.aws.ecs.model.UpdateTaskSetResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ecs_2.13-5.17.161.2-sources.jar: zio/aws/ecs/model/UpdateTaskSetResponse.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateTaskSetResponse(
    taskSet: Optional[zio.aws.ecs.model.TaskSet] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.UpdateTaskSetResponse = {
    import UpdateTaskSetResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.UpdateTaskSetResponse
      .builder()
      .optionallyWith(taskSet.map(value => value.buildAwsValue()))(_.taskSet)
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.UpdateTaskSetResponse.ReadOnly =
    zio.aws.ecs.model.UpdateTaskSetResponse.wrap(buildAwsValue())
}
object UpdateTaskSetResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.UpdateTaskSetResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.UpdateTaskSetResponse = zio.aws.ecs.model
      .UpdateTaskSetResponse(taskSet.map(value => value.asEditable))
    def taskSet: Optional[zio.aws.ecs.model.TaskSet.ReadOnly]
    def getTaskSet: ZIO[Any, AwsError, zio.aws.ecs.model.TaskSet.ReadOnly] =
      AwsError.unwrapOptionField("taskSet", taskSet)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.UpdateTaskSetResponse
  ) extends zio.aws.ecs.model.UpdateTaskSetResponse.ReadOnly {
    override val taskSet: Optional[zio.aws.ecs.model.TaskSet.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.taskSet())
        .map(value => zio.aws.ecs.model.TaskSet.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.UpdateTaskSetResponse
  ): zio.aws.ecs.model.UpdateTaskSetResponse.ReadOnly = new Wrapper(impl)
}
